@@ -6,7 +6,7 @@ import sys
 import traceback
 from functools import wraps
 import inspect
-from contextlib import contextmanager
+from contextlib import contextmanager, nested
 
 try:
     from abc import ABCMeta, abstractmethod
@@ -289,7 +289,7 @@ class Tests(object):
         self._tests = []
         for collection in tests:
             self.register(collection)
-        self._context = None
+        self._contexts = []
 
     def __iter__(self):
         return iter(self._tests)
@@ -301,17 +301,17 @@ class Tests(object):
         """Decorate a function as a test belonging to this collection."""
         @wraps(func)
         def wrapper():
-            if self._context is None:
-                func()
-            else:
-                with self._context() as context:
-                    if len(inspect.getargspec(func)[0]) != 0:
-                        if type(context) is tuple:  # type() is intentional
-                            func(*context)
+            with nested(*[ctx() for ctx in self._contexts]) as context:
+                if len(inspect.getargspec(func)[0]) != 0:
+                    args = []
+                    for arg in context:
+                        if type(arg) is tuple:  # type() is intentional
+                            args.extend(arg)
                         else:
-                            func(context)
-                    else:
-                        func()
+                            args.append(arg)
+                    func(*args)
+                else:
+                    func()
         self._tests.append(wrapper)
         return wrapper
 
@@ -362,16 +362,41 @@ class Tests(object):
         the sole argument, wrap it in a one-tuple or unsplat the args
         in the test.
 
+        You can have more than one context, which will be run in order
+        using :func:`contextlib.nested`, and their yields will be passed in
+        order to the test functions.
+
+        .. versionadded:: 0.2 Nested contexts.
+
         """
         func = contextmanager(func)
-        self._context = func
+        self._contexts.append(func)
         return func
 
     def register(self, tests):
-        """Merge in another test collection."""
+        """Merge in another test collection.
+
+        :param tests:
+            * A class, which is then instantiated and return allowing it to be
+              used as a decorator for :class:`TestBase` classes.
+            * A string, representing the import path to an iterable yielding
+              tests, in the form of ``'package.module.object'``.
+            * Otherwise any iterable object is assumed to yield tests.
+
+        Any of these can be passed in a list to the :class:`Tests`
+        constructor.
+
+        .. versionadded:: 0.2
+           Refer to collections by import path as a string
+
+        """
         if inspect.isclass(tests):
             self._tests.extend(tests())
             return tests
+        elif isinstance(tests, basestring):
+            package, collection = tests.rsplit('.', 1)
+            module = package.rsplit('.', 1)[1]
+            tests = getattr(__import__(package, fromlist=[module]), collection)
         self._tests.extend(tests)
 
     def test_suite(self):
@@ -414,6 +439,28 @@ class Tests(object):
                 reporter.success(test, out, err)
         reporter.finished()
 
+    def main(self, argv=sys.argv):
+        """Interface to :meth:`run` with command-line options.
+
+        ``-h``, ``--help``
+            Show a help message
+
+        ``-r NAME``, ``--reporter NAME``
+            Select reporter by name with :func:`get_reporter_by_name`
+
+        Remaining arguments are passed to the reporter.
+
+        .. versionadded:: 0.2
+
+        """
+        from optparse import OptionParser
+        parser = OptionParser()
+        parser.add_option('-r', '--reporter', metavar='NAME',
+                          help='select reporter by name')
+        options, args = parser.parse_args()
+        reporter = get_reporter_by_name(options.reporter)(*args)
+        self.run(reporter)
+
 
 def test(meth):
     """Mark a :class:`TestBase` method as a test and wrap it to run in the
